<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods\Recurring;

use Exception;
use QUI;
use QUI\ERP\Accounting\Invoice\Invoice;
use QUI\ERP\Accounting\Invoice\InvoiceView;
use QUI\ERP\Accounting\Payments\Payments;

/**
 * Class Card
 *
 * Stripe payment with credit card for recurring payments
 */
class Card extends AbstractBaseRecurringPayment
{
    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.Card.title');
    }

    /**
     * @return string
     */
    public function getDescription(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.Card.description');
    }

    /**
     * Get title for frontend
     *
     * @return string
     */
    public function getFrontendTitle(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.Recurring.Card.title');
    }

    /**
     * Get description for frontend
     *
     * @return string
     */
    public function getFrontendDescription(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.Recurring.Card.description');
    }

    /**
     * Get title for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepTitle(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.title.Card');
    }

    /**
     * Get description step for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepInfo(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.PaymentStep.info.Card');
    }

    /**
     * Return the payment icon (the URL path)
     * Can be overwritten
     *
     * @return string
     */
    public function getIcon(): string
    {
        return Payments::getInstance()->getHost() .
            URL_OPT_DIR .
            'quiqqer/payment-stripe/bin/images/Payment_Card.png';
    }

    /**
     * Get type string of Stripe PaymentMethod
     *
     * @return string
     */
    public function getPaymentMethodType(): string
    {
        return \Stripe\Card::OBJECT_NAME;
    }

    /**
     * Return the extra text for the invoice
     *
     * @param Invoice|InvoiceView $Invoice
     * @return mixed
     */
    public function getInvoiceInformationText($Invoice): string
    {
        try {
            return $Invoice->getCustomer()->getLocale()->get(
                'quiqqer/payment-stripe',
                'additional_invoice_text.Card'
            );
        } catch (Exception $Exception) {
            QUI\System\Log::writeException($Exception);
            return '';
        }
    }
}
