<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods\Recurring;

use Browser;
use Exception;
use QUI;
use QUI\ERP\Accounting\Invoice\Invoice;
use QUI\ERP\Accounting\Invoice\InvoiceTemporary;
use QUI\ERP\Accounting\Invoice\InvoiceView;
use QUI\ERP\Accounting\Payments\Payments;

/**
 * Class GooglePay
 *
 * Recurring payments via Google Pay
 */
class GooglePay extends AbstractRecurringBrowserPay
{
    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.GooglePay.title');
    }

    /**
     * @return string
     */
    public function getDescription(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.GooglePay.description');
    }

    /**
     * Get title for frontend
     *
     * @return string
     */
    public function getFrontendTitle(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.Recurring.GooglePay.title');
    }

    /**
     * Get description for frontend
     *
     * @return string
     */
    public function getFrontendDescription(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.Recurring.GooglePay.description');
    }

    /**
     * Get title for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepTitle(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.title.GooglePay');
    }

    /**
     * Get description step for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepInfo(): string
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.info.GooglePay');
    }

    /**
     * Get type of Browser this BrowserPay works with
     *
     * @return string[]
     */
    public function getBrowserTypes(): array
    {
        return [
            Browser::BROWSER_CHROME
        ];
    }

    /**
     * Return the payment icon (the URL path)
     * Can be overwritten
     *
     * @return string
     */
    public function getIcon(): string
    {
        return Payments::getInstance()->getHost() .
            URL_OPT_DIR .
            'quiqqer/payment-stripe/bin/images/Payment_GooglePay.png';
    }

    /**
     * Return the extra text for the invoice
     *
     * @param Invoice|InvoiceView|InvoiceTemporary $Invoice |InvoiceView $Invoice
     * @return mixed
     */
    public function getInvoiceInformationText(Invoice|InvoiceView|InvoiceTemporary $Invoice): string
    {
        try {
            return $Invoice->getCustomer()->getLocale()->get(
                'quiqqer/payment-stripe',
                'additional_invoice_text.GooglePay'
            );
        } catch (Exception $Exception) {
            QUI\System\Log::writeException($Exception);
            return '';
        }
    }
}
